==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=hu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'csak a leendő cikkek részére (nincs hatás az adatbázisban).',
	'bouton_radio_articles_tous' => 'minden cikknek, kivétel nélkül.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'minden cikknek, kivéve azokat, melynek nincs aktiválva a fóruma.',
	'bouton_radio_enregistrement_obligatoire' => 'Beíratkozás kötelező (a felhasználóknak be kell iratkozniuk azzal, hogy adják email címüket mielőbb küldhessenek anyagokat).',
	'bouton_radio_moderation_priori' => 'Előzetes moderálás (a
 küldött anyagok csak az adminisztrátorok adta jováhagyást kerülnek nyilvánosságra).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderálva beiratkozásnál',
	'bouton_radio_modere_posteriori' => 'utólag moderált', # MODIF
	'bouton_radio_modere_priori' => 'elözőleg moderálva', # MODIF
	'bouton_radio_publication_immediate' => 'Üzenetek azonnali publikálása
 (a küldött anyagok már küldéskor megjelennek, az adminisztrátorok későb tudják törölni).',

	// F
	'form_pet_message_commentaire' => 'Üzenet, hozzászólás ?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'Már nincs hozzáférése ezekhez a fórumokhoz.',
	'forum_attention_dix_caracteres' => '<b>Vigyázat !</b> Az üzenetének legalább 10 karaktert kell tartalmaznia.',
	'forum_attention_trois_caracteres' => '<b>Vigyázat !</b> A címnek legalább három karaktert kell tartalmaznia.',
	'forum_attention_trop_caracteres' => '<b>Figyelem !</b> az üzenete túl hosszú (@compte@ karakter) : legfeljebb @max@ karakterből állhat.', # MODIF
	'forum_avez_selectionne' => 'Kijelölt :',
	'forum_cliquer_retour' => 'Kattintson <a href=\'@retour_forum@\'>ide</a> a folytatáshoz.',
	'forum_forum' => 'fórum',
	'forum_info_modere' => 'Ez a fórum előre moderált : az Ön hozzászólása csak azután jelenik meg, hogy a honlap egyik adminisztrátora jóváhagyta.', # MODIF
	'forum_lien_hyper' => '<b>Hiperhivatkozás</b> (választható)', # MODIF
	'forum_message_definitif' => 'Végleges üzenet: küldés a honlapra',
	'forum_message_trop_long' => 'Az Ön üzenete túl hosszú. A maximális méret 20 000 karakter.', # MODIF
	'forum_ne_repondez_pas' => 'Ne erre az emailre válaszoljon, hanem a fórumon a következő címen:', # MODIF
	'forum_page_url' => '(Amennyiben az Ön üzenete egy interneten publikált, vagy további információt tartalmazó oldalra vonatkozik, akkor adja meg az oldal nevét, illetve URL címét.)',
	'forum_poste_par' => 'Az üzenetet @parauteur@ küldte, "@titre@" című cikkére válaszul.', # MODIF
	'forum_qui_etes_vous' => '<b>Kicsoda Ön?</b> (nem kötelező)', # MODIF
	'forum_texte' => 'Üzenetének szövege:', # MODIF
	'forum_titre' => 'Tárgy:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Érvényesítse választását',
	'forum_voir_avant' => 'Küldés előtti előnézet megtekintése', # MODIF
	'forum_votre_email' => 'Az Ön email címe:', # MODIF
	'forum_votre_nom' => 'Az Öne neve (vagy beceneve):', # MODIF
	'forum_vous_enregistrer' => 'A fórum használatához
  kérjük, először regisztráljon. Lentebb adja meg
  a személyes azonosítót,
amit kapott. Amennyiben nincs regisztrálva, akkor',
	'forum_vous_inscrire' => 'regisztráljon.',

	// I
	'icone_poster_message' => 'Üzenet küldése',
	'icone_suivi_forum' => 'A nyilvános fórum megfigyelése : @nb_forums@ hozzászlás',
	'icone_suivi_forums' => 'Figyelni/kezelni a fórumokat',
	'icone_supprimer_message' => 'Az üzenet törlése',
	'icone_valider_message' => 'Az üzenet érvényesítése',
	'info_activer_forum_public' => '<i>A nyilvános fórumok aktiválására, válassza az alapértelmezett
 móderálási módjukat:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Alkalmazni ezt a moderálási választást :',
	'info_desactiver_forum_public' => 'A nyilvános fórumok kikapcsolása.
 A nyilvános fórumokat egyenként lehet engedélyezni
 a cikkeknél ; tiltva lesznek a rovatoknál, híreknél, stb.',
	'info_envoi_forum' => 'Fórumok küldése a cikkek szerzőinek',
	'info_fonctionnement_forum' => 'Fórum működése :',
	'info_gauche_suivi_forum_2' => 'A <i>fórumok megfigyelése</i> nevű oldal a honlap egyik kezelési eszkőze (és nem pedig vitás, vagy szerzői rész). A honlap összes (nyilvános, ill. privát rész) fórumainak hozzászólásait jeleníti meg, és ezeknek kezelését teszi lehetővé.', # MODIF
	'info_liens_syndiques_3' => 'fórumok',
	'info_liens_syndiques_4' => 'vannak',
	'info_liens_syndiques_5' => 'fórum',
	'info_liens_syndiques_6' => 'van',
	'info_liens_syndiques_7' => 'jóváhagyás alatt',
	'info_mode_fonctionnement_defaut_forum_public' => 'Nyilvános fórumok alapértelmezett működési módszere',
	'info_option_email' => 'Ha egy látogató üzenetet küld egy új üzenetet a cikkhez csatolt fórumba,
  akkor a szerzők erről az üzenetről értesülhetnek emailen. Szeretne használni ezt az opciót ?', # MODIF
	'info_pas_de_forum' => 'Nincs fórum',
	'item_activer_forum_administrateur' => 'Admninisztrátori fórum aktiválása',
	'item_desactiver_forum_administrateur' => 'Az adminisztrátori fórumok inaktiválása',

	// L
	'lien_reponse_article' => 'Hozzászólás a cikkről',
	'lien_reponse_breve_2' => 'Hozzászólás a hírhez',
	'lien_reponse_rubrique' => 'Hozzászólás a rubrikához',
	'lien_reponse_site_reference' => 'Hozzászólás a felvett honlaphoz :', # MODIF

	// O
	'onglet_messages_internes' => 'Belső üzenetek',
	'onglet_messages_publics' => 'Nyilvános üzenetek',
	'onglet_messages_vide' => 'Szöveg nélküli üzenetek',

	// R
	'repondre_message' => 'Válaszolni erre az üzenetre',

	// T
	'titre_cadre_forum_administrateur' => 'Privát adminisztrátori fórum',
	'titre_cadre_forum_interne' => 'Belső fórum',
	'titre_forum' => 'Fórum',
	'titre_forum_suivi' => 'A fórumok megfigyelése',
	'titre_page_forum_suivi' => 'Fórumok megfigyelése'
);

==> spip_4.2.12+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=hu
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'csak a leendő cikkek részére (nincs hatás az adatbázisban).',
	'bouton_radio_articles_tous' => 'minden cikknek, kivétel nélkül.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'minden cikknek, kivéve azokat, melynek nincs aktiválva a fóruma.',
	'bouton_radio_enregistrement_obligatoire' => 'Beíratkozás kötelező (a felhasználóknak be kell iratkozniuk azzal, hogy adják email címüket mielőbb küldhessenek anyagokat).',
	'bouton_radio_moderation_priori' => 'Előzetes moderálás (a
 küldött anyagok csak az adminisztrátorok adta jováhagyást kerülnek nyilvánosságra).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderálva beiratkozásnál',
	'bouton_radio_modere_posteriori' => 'utólag moderált', # MODIF
	'bouton_radio_modere_priori' => 'elözőleg moderálva', # MODIF
	'bouton_radio_publication_immediate' => 'Üzenetek azonnali publikálása
 (a küldött anyagok már küldéskor megjelennek, az adminisztrátorok későb tudják törölni).',

	// F
	'form_pet_message_commentaire' => 'Üzenet, hozzászólás ?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'Már nincs hozzáférése ezekhez a fórumokhoz.',
	'forum_attention_dix_caracteres' => '<b>Vigyázat !</b> Az üzenetének legalább 10 karaktert kell tartalmaznia.',
	'forum_attention_trois_caracteres' => '<b>Vigyázat !</b> A címnek legalább három karaktert kell tartalmaznia.',
	'forum_attention_trop_caracteres' => '<b>Figyelem !</b> az üzenete túl hosszú (@compte@ karakter) : legfeljebb @max@ karakterből állhat.', # MODIF
	'forum_avez_selectionne' => 'Kijelölt :',
	'forum_cliquer_retour' => 'Kattintson <a href=\'@retour_forum@\'>ide</a> a folytatáshoz.',
	'forum_forum' => 'fórum',
	'forum_info_modere' => 'Ez a fórum előre moderált : az Ön hozzászólása csak azután jelenik meg, hogy a honlap egyik adminisztrátora jóváhagyta.', # MODIF
	'forum_lien_hyper' => '<b>Hiperhivatkozás</b> (választható)', # MODIF
	'forum_message_definitif' => 'Végleges üzenet: küldés a honlapra',
	'forum_message_trop_long' => 'Az Ön üzenete túl hosszú. A maximális méret 20 000 karakter.', # MODIF
	'forum_ne_repondez_pas' => 'Ne erre az emailre válaszoljon, hanem a fórumon a következő címen:', # MODIF
	'forum_page_url' => '(Amennyiben az Ön üzenete egy interneten publikált, vagy további információt tartalmazó oldalra vonatkozik, akkor adja meg az oldal nevét, illetve URL címét.)',
	'forum_poste_par' => 'Az üzenetet @parauteur@ küldte, "@titre@" című cikkére válaszul.', # MODIF
	'forum_qui_etes_vous' => '<b>Kicsoda Ön?</b> (nem kötelező)', # MODIF
	'forum_texte' => 'Üzenetének szövege:', # MODIF
	'forum_titre' => 'Tárgy:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Érvényesítse választását',
	'forum_voir_avant' => 'Küldés előtti előnézet megtekintése', # MODIF
	'forum_votre_email' => 'Az Ön email címe:', # MODIF
	'forum_votre_nom' => 'Az Öne neve (vagy beceneve):', # MODIF
	'forum_vous_enregistrer' => 'A fórum használatához
  kérjük, először regisztráljon. Lentebb adja meg
  a személyes azonosítót,
amit kapott. Amennyiben nincs regisztrálva, akkor',
	'forum_vous_inscrire' => 'regisztráljon.',

	// I
	'icone_poster_message' => 'Üzenet küldése',
	'icone_suivi_forum' => 'A nyilvános fórum megfigyelése : @nb_forums@ hozzászlás',
	'icone_suivi_forums' => 'Figyelni/kezelni a fórumokat',
	'icone_supprimer_message' => 'Az üzenet törlése',
	'icone_valider_message' => 'Az üzenet érvényesítése',
	'info_activer_forum_public' => '<i>A nyilvános fórumok aktiválására, válassza az alapértelmezett
 móderálási módjukat:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Alkalmazni ezt a moderálási választást :',
	'info_desactiver_forum_public' => 'A nyilvános fórumok kikapcsolása.
 A nyilvános fórumokat egyenként lehet engedélyezni
 a cikkeknél ; tiltva lesznek a rovatoknál, híreknél, stb.',
	'info_envoi_forum' => 'Fórumok küldése a cikkek szerzőinek',
	'info_fonctionnement_forum' => 'Fórum működése :',
	'info_gauche_suivi_forum_2' => 'A <i>fórumok megfigyelése</i> nevű oldal a honlap egyik kezelési eszkőze (és nem pedig vitás, vagy szerzői rész). A honlap összes (nyilvános, ill. privát rész) fórumainak hozzászólásait jeleníti meg, és ezeknek kezelését teszi lehetővé.', # MODIF
	'info_liens_syndiques_3' => 'fórumok',
	'info_liens_syndiques_4' => 'vannak',
	'info_liens_syndiques_5' => 'fórum',
	'info_liens_syndiques_6' => 'van',
	'info_liens_syndiques_7' => 'jóváhagyás alatt',
	'info_mode_fonctionnement_defaut_forum_public' => 'Nyilvános fórumok alapértelmezett működési módszere',
	'info_option_email' => 'Ha egy látogató üzenetet küld egy új üzenetet a cikkhez csatolt fórumba,
  akkor a szerzők erről az üzenetről értesülhetnek emailen. Szeretne használni ezt az opciót ?', # MODIF
	'info_pas_de_forum' => 'Nincs fórum',
	'item_activer_forum_administrateur' => 'Admninisztrátori fórum aktiválása',
	'item_desactiver_forum_administrateur' => 'Az adminisztrátori fórumok inaktiválása',

	// L
	'lien_reponse_article' => 'Hozzászólás a cikkről',
	'lien_reponse_breve_2' => 'Hozzászólás a hírhez',
	'lien_reponse_rubrique' => 'Hozzászólás a rubrikához',
	'lien_reponse_site_reference' => 'Hozzászólás a felvett honlaphoz :', # MODIF

	// O
	'onglet_messages_internes' => 'Belső üzenetek',
	'onglet_messages_publics' => 'Nyilvános üzenetek',
	'onglet_messages_vide' => 'Szöveg nélküli üzenetek',

	// R
	'repondre_message' => 'Válaszolni erre az üzenetre',

	// T
	'titre_cadre_forum_administrateur' => 'Privát adminisztrátori fórum',
	'titre_cadre_forum_interne' => 'Belső fórum',
	'titre_forum' => 'Fórum',
	'titre_forum_suivi' => 'A fórumok megfigyelése',
	'titre_page_forum_suivi' => 'Fórumok megfigyelése',
];
